@@ -3,7 +3,7 @@
 ob_start(); // just in case
 
 
-header("Expires: -1"); 
+header("Expires: -1");
 
 header("Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0");
 header("Pragma: no-cache");
@@ -13,7 +13,7 @@ define ('SERVER_ROOT', $_SERVER['LS_SERVER_ROOT']);
 
 ini_set('include_path',
 SERVER_ROOT . 'admin/html/lib/:' .
-SERVER_ROOT . 'admin/html/lib/ows/:' .
+SERVER_ROOT . 'admin/html/lib/owsda/:' .
 SERVER_ROOT . 'admin/html/view/:.');
 
 // **PREVENTING SESSION HIJACKING**
